# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GatewayLogConfig',
    'GatewayLogConfigSls',
    'GatewayNetworkAccessConfig',
    'GatewayVpc',
    'GatewayVswitch',
    'GatewayZoneConfig',
]

@pulumi.output_type
class GatewayLogConfig(dict):
    def __init__(__self__, *,
                 sls: Optional['outputs.GatewayLogConfigSls'] = None):
        """
        :param 'GatewayLogConfigSlsArgs' sls: Sls See `sls` below.
        """
        if sls is not None:
            pulumi.set(__self__, "sls", sls)

    @property
    @pulumi.getter
    def sls(self) -> Optional['outputs.GatewayLogConfigSls']:
        """
        Sls See `sls` below.
        """
        return pulumi.get(self, "sls")


@pulumi.output_type
class GatewayLogConfigSls(dict):
    def __init__(__self__, *,
                 enable: Optional[bool] = None):
        """
        :param bool enable: Enable Log Service
        """
        if enable is not None:
            pulumi.set(__self__, "enable", enable)

    @property
    @pulumi.getter
    def enable(self) -> Optional[bool]:
        """
        Enable Log Service
        """
        return pulumi.get(self, "enable")


@pulumi.output_type
class GatewayNetworkAccessConfig(dict):
    def __init__(__self__, *,
                 type: Optional[str] = None):
        """
        :param str type: Network Access Type
        """
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        """
        Network Access Type
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GatewayVpc(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "vpcId":
            suggest = "vpc_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in GatewayVpc. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        GatewayVpc.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        GatewayVpc.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 vpc_id: str,
                 name: Optional[str] = None):
        """
        :param str vpc_id: The VPC network ID.
        :param str name: The name of the VPC gateway.
        """
        pulumi.set(__self__, "vpc_id", vpc_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> str:
        """
        The VPC network ID.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        The name of the VPC gateway.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GatewayVswitch(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "vswitchId":
            suggest = "vswitch_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in GatewayVswitch. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        GatewayVswitch.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        GatewayVswitch.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: Optional[str] = None,
                 vswitch_id: Optional[str] = None):
        """
        :param str name: The name of the VPC gateway.
        :param str vswitch_id: The ID of the virtual switch.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        The name of the VPC gateway.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[str]:
        """
        The ID of the virtual switch.
        """
        return pulumi.get(self, "vswitch_id")


@pulumi.output_type
class GatewayZoneConfig(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "selectOption":
            suggest = "select_option"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in GatewayZoneConfig. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        GatewayZoneConfig.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        GatewayZoneConfig.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 select_option: str):
        """
        :param str select_option: Availability Zone Options
        """
        pulumi.set(__self__, "select_option", select_option)

    @property
    @pulumi.getter(name="selectOption")
    def select_option(self) -> str:
        """
        Availability Zone Options
        """
        return pulumi.get(self, "select_option")


